@@ -1,4 +1,4 @@
-from .config import GMAIL_SMTP_SERVER
+from .config import GMAIL_SMTP_SERVER, GMAIL_IMAP_SERVER
 from .mailer import Mailer
 
 
@@ -7,3 +7,4 @@ class GmailMailer(Mailer):
     Gmail mail sender library
     """
     smtp_server = GMAIL_SMTP_SERVER
+    imap_server = GMAIL_IMAP_SERVER
