@@ -1,4 +1,4 @@
-from .config import YANDEX_SMTP_SERVER
+from .config import YANDEX_SMTP_SERVER, YANDEX_IMAP_SERVER
 from .mailer import Mailer
 
 
@@ -7,3 +7,4 @@ class YandexMailer(Mailer):
     Класс, реализующий библиотеку для отправки электронной почты с помощью яндекс
     """
     smtp_server = YANDEX_SMTP_SERVER
+    imap_server = YANDEX_IMAP_SERVER
